%DFT_of_a_few_tones
% Demonstration of the Discrete Fourier Transform. A few sine waves are
% samples and combined. A DFT is then performed and then plotted.
%
% LAST UPDATED by Andy French. Dec 2016

function DFT_of_a_few_tones

%Fontsize for graphs
fsize = 18;

%Define maximum frequency /Hz for DFT output
fmax = 4;

%Define maximum time for plot /s (note a possibly longer sample time is
%used to form the DFT - this is set by N. Note higher N will produce
%a sharper DFT Power Spectrum - i.e. with individual freqencies more
%clearly resolved).
tmax = 10;

%Determine number of time data points points
N = 1000;

%Define number of frequency evaluation points
Nf = 1000;

%Define sample rate /Hz (Must be higher than highest frequency tone -
%Nyquist criterion). Note raising fs will broaden the peaks in the Power
%Spectrum (i.e. since the frequencies of interest will be a smaller
%fraction of [0,fs]
fs = 100;

%Define tone frequencies /Hz
f1 = 0.8;
f2 = 1.6;
f3 = 2.5;

%Define tone amplitudes
a1 = 1;
a2 = 2;
a3 = 1.5;

%Define tone phases /radians
phi1 = 0;
phi2 = pi/4;
phi3 = pi/6;

%Determine time (s) and frequency (Hz) arrays
t = (0:N-1)/fs;
f = linspace(0,fmax,Nf);

%Determine signal
x = a1*sin( 2*pi*f1*t - phi1 ) + a2*sin( 2*pi*f2*t - phi2 ) + a3*sin( 2*pi*f3*t - phi3 );

%Determine DFT
ff = repmat( f, [N,1] );
n = repmat( (1:N).', [1,Nf] );
xx = repmat( x.',[1,Nf] );
y = sum( xx.*exp( -2*pi*1i*(n-1).*ff/fs ),1 );

%Normalize DFT
y = y/N;

%Plot signal and normalized power spectrum
figure('color',[1 1 1],'name','DFT of a few tones')
plot( t, x );
xlim([0,tmax]);
xlabel('time /s','fontsize',fsize);
ylabel('Amplitude','fontsize',fsize);
title('Addition of three pure tones','fontsize',fsize);
grid on
set(gca,'fontsize',fsize)
print(gcf,'three pure tones.png','-dpng','-r300');
clf;
plot( f, y.*conj(y) );
xlabel('frequency /Hz','fontsize',fsize);
ylabel('Normalized spectral power','fontsize',fsize);
title('Addition of three pure tones - Normalized Power Spectrum','fontsize',fsize);
grid on
set(gca,'fontsize',fsize)
print(gcf,'three pure tones spectrum.png','-dpng','-r300');
close(gcf);

%End of code