%square_wave_fourier_series
% Plots Fourier series of a square wave
%
% LAST UPDATED by Andy French. Dec 2016

function square_wave_fourier_series

%Number of plot points
N = 1000;

%Periodic length L
L = 1;

%Number of periods
Np = 2;

%Range of x
xmin = 0;
xmax = Np*L;

%Fontsize
fsize = 18;

%Max k for Fourier series
kmax = 50;

%

%Define x vector
x = linspace(xmin,xmax,N);

%Define square wave
xxs = [0,L/2,L/2,L]; 
xs = xxs;
for n=1:Np-1
    xs = [xs, xxs+ n*L];
end
ys = [1,1,-1,-1]; ys = repmat(ys,[1,Np]);

%Define Fourier Series
y = zeros(1,N);
for k=0:kmax
    y = y + (4/pi)*(1/(2*k+1))*sin( 2*(2*k+1)*pi*x/L );
end

%Plot square wave and overlay Fourier Series
figure('color',[1 1 1],'Name','Fourier Series of Square Wave');
plot( xs,ys,'b-'); hold on;
plot( x, y, 'r-');
xlabel('x','fontsize',fsize);
ylabel('y','fontsize',fsize);
set(gca,'fontsize',fsize);
title(['Square wave Fourier Series: kmax = ',num2str(kmax)],'fontsize',fsize);
xlim([0,Np*L]);
ylim([-1.5,1.5]);
grid on;
print( gcf,'square wave fourier series.png','-dpng','-r300' );

%End of code